@@ -8,9 +8,7 @@ from django.contrib.auth.models import User
 from custom.utils import *
 from django.db.models import Count
 # pdf library
-from io import BytesIO
-from django.template.loader import get_template
-from xhtml2pdf import pisa
+
 from django.contrib.auth.decorators import login_required
 from datetime import date
 # Create your views here.
@@ -328,9 +326,6 @@ def administration_report(request):
 			elif 'excel' in request.POST:
 				data["page"] = "excel"
 				return render(request,"administration_layout/report/A1_report.html",data)
-			elif 'pdf' in request.POST:
-				pdf = render_to_pdf('administration_layout/pdf/pdf_desizaun_konsellu_suku.html', data)
-				return HttpResponse(pdf, content_type='application/pdf')
 
 		if administrationReport == "A2":
 			decision_type = "Xefe Suku"
@@ -349,9 +344,6 @@ def administration_report(request):
 			elif 'excel' in request.POST:
 				data["page"] = "excel"
 				return render(request,"administration_layout/report/A2_report.html",data)
-			elif 'pdf' in request.POST:
-				pdf = render_to_pdf('administration_layout/pdf/pdf_desizaun_xefe_suku.html', data)
-				return HttpResponse(pdf, content_type='application/pdf')
 
 		if administrationReport == "A3":
 			if request.user.groups.all()[0].name == "admin":
@@ -368,9 +360,6 @@ def administration_report(request):
 			elif 'excel' in request.POST:
 				data["page"] = "excel"
 				return render(request,"administration_layout/report/A3_report.html",data)
-			elif 'pdf' in request.POST:
-				pdf = render_to_pdf('administration_layout/pdf/pdf_livru_inventariu_suku.html', data)
-				return HttpResponse(pdf, content_type='application/pdf')
 
 		if administrationReport == "A4":
 			if request.user.groups.all()[0].name == "admin":
@@ -387,9 +376,6 @@ def administration_report(request):
 			elif 'excel' in request.POST:
 				data["page"] = "excel"
 				return render(request,"administration_layout/report/A4_report.html",data)
-			elif 'pdf' in request.POST:
-				pdf = render_to_pdf('administration_layout/pdf/pdf_livru_ajenda_surat_sai.html', data)
-				return HttpResponse(pdf, content_type='application/pdf')
 			
 		if administrationReport == "A5":
 			if request.user.groups.all()[0].name == "admin":
@@ -406,9 +392,6 @@ def administration_report(request):
 			elif 'excel' in request.POST:
 				data["page"] = "excel"
 				return render(request,"administration_layout/report/A5_report.html",data)
-			elif 'pdf' in request.POST:
-				pdf = render_to_pdf('administration_layout/pdf/pdf_livru_ajenda_surat_tama.html', data)
-				return HttpResponse(pdf, content_type='application/pdf')
 
 		if administrationReport == "A6":
 			if request.user.groups.all()[0].name == "admin":
@@ -425,9 +408,6 @@ def administration_report(request):
 			if 'excel' in request.POST:
 				data["page"] = "excel"
 				return render(request,"administration_layout/report/A6_report.html",data)
-			elif 'pdf' in request.POST:
-				pdf = render_to_pdf('administration_layout/pdf/pdf_livru_espedisaun.html', data)
-				return HttpResponse(pdf, content_type='application/pdf')
 
 		if administrationReport == "A7":
 			if request.user.groups.all()[0].name == "admin":
@@ -444,9 +424,6 @@ def administration_report(request):
 			if 'excel' in request.POST:
 				data["page"] = "excel"
 				return render(request,"administration_layout/report/A7_report.html",data)
-			elif 'pdf' in request.POST:
-				pdf = render_to_pdf('administration_layout/pdf/pdf_livru_lideransa_komunitariu.html', data)
-				return HttpResponse(pdf, content_type='application/pdf')
 			
 		if administrationReport == "A10":
 			if request.user.groups.all()[0].name == "admin":
@@ -463,9 +440,6 @@ def administration_report(request):
 			if 'excel' in request.POST:
 				data["page"] = "excel"
 				return render(request,"administration_layout/report/A10_report.html",data)
-			elif 'pdf' in request.POST:
-				pdf = render_to_pdf('administration_layout/pdf/pdf_rejistu_keixa_suku.html', data)
-				return HttpResponse(pdf, content_type='application/pdf')
 
 		if administrationReport == "A11":
 			if request.user.groups.all()[0].name == "admin":
@@ -482,9 +456,6 @@ def administration_report(request):
 			if 'excel' in request.POST:
 				data["page"] = "excel"
 				return render(request,"administration_layout/report/A11_report.html",data)
-			elif 'pdf' in request.POST:
-				pdf = render_to_pdf('administration_layout/pdf/pdf_rejistu_bainaka_suku.html', data)
-				return HttpResponse(pdf, content_type='application/pdf')
 			
 	context = {
 		'title':"Livru Relatóriu Sira",
@@ -495,22 +466,6 @@ def administration_report(request):
 
 
 #========================= all pdf functions============================
-@login_required
-def pdfMinutaEnkontruSuku(request,hashid):
-	if request.user.groups.all()[0].name == "admin":
-		userAddress = ''
-		meetingData = get_object_or_404(MeetingTime,hashed=hashid)
-		meetingDecision = get_object_or_404(Decision,hashed=meetingData.decision.hashed)
-		villageAdviseAbsentInDecision = DecisionDetail.objects.filter(decision__hashed=meetingDecision.hashed,attendance="No")
-	else:
-		userAddress = get_object_or_404(EmployeeUser,user__id=request.user.id)
-		meetingData = get_object_or_404(MeetingTime,hashed=hashid)
-		meetingDecision = get_object_or_404(Decision,hashed=meetingData.decision.hashed)
-		villageAdviseAbsentInDecision = DecisionDetail.objects.filter(decision__hashed=meetingDecision.hashed,attendance="No")
-	data ={"userAddress":userAddress,'meetingData':meetingData,'meetingDetail':villageAdviseAbsentInDecision,"title":"PDF Minutas Enkontru Suku"}
-	pdf = render_to_pdf('administration_layout/pdf/pdf_minuta_enkontru_suku.html', data)
-	return HttpResponse(pdf, content_type='application/pdf')
-
 @login_required
 def printMinutaEnkontruSuku(request,hashid):
 	if request.user.groups.all()[0].name == "admin":
@@ -526,37 +481,6 @@ def printMinutaEnkontruSuku(request,hashid):
 	data ={"userAddress":userAddress,'meetingData':meetingData,'meetingDetail':villageAdviseAbsentInDecision,"title":"Print Minutas Enkontru Suku"}
 	return render(request,"administration_layout/report/A9_report.html",data)
 
-@login_required
-def pdfMeetingAttendance(request,hashid):
-	if request.user.groups.all()[0].name == "admin":
-		decision = get_object_or_404(Decision,hashed=hashid)
-		attendance = []
-		otherList = Attendance.objects.filter(decision=decision)
-		villageAdviseAttendance = DecisionDetail.objects.filter(decision=decision,attendance="Yes")
-	else:
-		userAddress = get_object_or_404(EmployeeUser,user__id=request.user.id)
-		decision = get_object_or_404(Decision,hashed=hashid)
-		attendance = []
-		otherList = Attendance.objects.filter(decision=decision,village=userAddress.employee.village)
-		villageAdviseAttendance = DecisionDetail.objects.filter(decision=decision,attendance="Yes")
-	for i in villageAdviseAttendance.iterator():
-		attendance.append({
-			"naran":i.villageAdvise.population.name,
-			"instituition":"Konsellu Suku",
-			"position":i.villageAdvise.position,
-			"asinatura":""
-		})
-	for i in otherList.iterator():
-		attendance.append({
-			"naran":i.name,
-			"instituition":i.instituition,
-			"position":i.position,
-			"asinatura":""
-		})
-	data ={"decision":decision,"attendanceList":attendance,"title":"Print Lista Prezensa Suku"}
-	pdf = render_to_pdf('administration_layout/pdf/pdf_lista_prezensa.html', data)
-	return HttpResponse(pdf, content_type='application/pdf')
-
 @login_required
 def printMeetingAttendance(request,hashid):
 	if request.user.groups.all()[0].name == "admin":
@@ -623,13 +547,3 @@ def printDecisioResult1(request,hashid):
 	decision = get_object_or_404(Decision,decision_type="Xefe Suku",hashed=hashid)
 	data ={"decision_type":decision_type,"decision":decision,"title":f"Print Detaillu Desizaun Xefe Suku"} 
 	return render(request,"administration_layout/report/A2a_report.html",data)
-
-
-def render_to_pdf(template_src, context_dict={}):
-    template = get_template(template_src)
-    html  = template.render(context_dict)
-    result = BytesIO()
-    pdf = pisa.pisaDocument(BytesIO(html.encode("ISO-8859-1")), result)
-    if not pdf.err:
-        return HttpResponse(result.getvalue(), content_type='application/pdf')
-    return None
