@@ -6,12 +6,10 @@ from employee.models import *
 from django.contrib.auth.models import User
 from custom.utils import *
 # pdf library
-from io import BytesIO
-from django.template.loader import get_template
-from xhtml2pdf import pisa
 from django.contrib.auth.decorators import login_required
 from datetime import date
 from main.decorators import *
+from population.utils import getlastid_kinos
 # Create your views here.
 @login_required
 def villageAdviseDecisionList(request):
@@ -38,7 +36,7 @@ def addDecisionVillageAdvise(request):
 	villageAdviseList = CommunityLeadership.objects.filter(status="Yes",village=userAddress.employee.village,position__name__in=("Xefe Suku","Xefe Aldeia","Delgadu","Delgada","Reprezentante Juventude Feto","Reprezentante Juventude Mane","Lia Nain"))
 	yearList = Year.objects.all()
 	if request.method == "POST":
-		newid = getjustnewid(Decision)
+		newid = getlastid_kinos(Decision,str(userAddress.employee.village.id))
 		hashid = hash_md5(str(newid))
 		decision_type = "Konsellu Suku"
 		meeting_date = request.POST.get("meeting_date")
@@ -49,7 +47,6 @@ def addDecisionVillageAdvise(request):
 		year = request.POST.get("year")
 		year = get_object_or_404(Year,year=year)
 		user_created = get_object_or_404(User,id=request.user.id)
-		userAddress = get_object_or_404(EmployeeUser,user__id=request.user.id)
 		villageAdviseData = request.POST.getlist('villageAdvise')
 		# kondisaun bainhira konsellu suku la iha
 		if villageAdviseData == []:
@@ -93,9 +90,10 @@ def addDecisionVillageAdvise(request):
 @allowed_users(allowed_roles=['sec','xefe'])
 def addDecisionResult(request,decisionHashid):
 	group = request.user.groups.all()[0].name
+	userAddress = get_object_or_404(EmployeeUser,user__id=request.user.id)
 	decisionData = get_object_or_404(Decision, hashed=decisionHashid)
 	if request.method == "POST":
-		newid = getjustnewid(VotingResult)
+		newid = getlastid_kinos(VotingResult,str(userAddress.employee.village.id))
 		hashid = hash_md5(str(newid))
 		form = DecisionResultForm(request.POST)
 		if form.is_valid():
@@ -104,7 +102,6 @@ def addDecisionResult(request,decisionHashid):
 			instance.hashed = hashid
 			instance.decision = decisionData
 			user = get_object_or_404(User, id=request.user.id)
-			userAddress = get_object_or_404(EmployeeUser,user__id=request.user.id)
 			instance.user_created = user
 			instance.municipality=userAddress.employee.municipality
 			instance.administrativepost=userAddress.employee.administrativepost
@@ -128,9 +125,10 @@ def addDecisionResult(request,decisionHashid):
 @allowed_users(allowed_roles=['sec','xefe'])
 def addDecisionResult1(request,decisionHashid):
 	group = request.user.groups.all()[0].name
+	userAddress = get_object_or_404(EmployeeUser,user__id=request.user.id)
 	decisionData = get_object_or_404(Decision, hashed=decisionHashid)
 	if request.method == "POST":
-		newid = getjustnewid(VotingResult)
+		newid = getlastid_kinos(VotingResult,str(userAddress.employee.village.id))
 		hashid = hash_md5(str(newid))
 		form = DecisionResultForm(request.POST)
 		if form.is_valid():
@@ -140,7 +138,6 @@ def addDecisionResult1(request,decisionHashid):
 			instance.decision = decisionData
 			user = get_object_or_404(User, id=request.user.id)
 			instance.user_created = user
-			userAddress = get_object_or_404(EmployeeUser,user__id=request.user.id)
 			instance.municipality=userAddress.employee.municipality
 			instance.administrativepost=userAddress.employee.administrativepost
 			instance.village=userAddress.employee.village
@@ -243,7 +240,7 @@ def addDecisionVillageChief(request):
 	villageAdviseList = CommunityLeadership.objects.filter(status="Yes",village=userAddress.employee.village,position__name__in=("Xefe Suku","Xefe Aldeia","Delgadu","Delgada","Reprezentante Juventude Feto","Reprezentante Juventude Mane","Lia Nain"))
 	yearList = Year.objects.all()
 	if request.method == "POST":
-		newid = getjustnewid(Decision)
+		newid = getlastid_kinos(Decision,str(userAddress.employee.village.id))
 		hashid = hash_md5(str(newid))
 		decision_type = "Xefe Suku"
 		meeting_date = request.POST.get("meeting_date")
